@@ -15,7 +15,7 @@ class SOCOClient(object):
             self._server_url = host
 
         # MONITOR
-        self.status_url = self._server_url + '/v1/index/status'
+        self.status_url = self._server_url + '/v1/op/status'
 
         # QUERY
         self.query_url = self._server_url + '/v1/search/query'
@@ -68,22 +68,36 @@ class SOCOClient(object):
             is_first = i == 0
             yield l[i:i + n]
 
-    def wait_for_ready(self, check_frequency=15, timeout=-1, verbose=False):
+    def printTable(self, myDict, colList=None):
+        new_dicts = []
+        for item in myDict.values():
+            new_dict = dict()
+            for k in ["job_id","done","total", "enqueued_at","queue","status","started_at","type"]:
+                if k in item:
+                    new_dict[k] = item[k]
+            new_dicts.append(new_dict)
+        myDict = new_dicts
+        if not colList: colList = list(myDict[0].keys() if myDict else [])
+        myList = [colList]  # 1st row = header
+        for item in myDict: myList.append([str(item[col] if item[col] is not None else '') for col in colList])
+        colSize = [max(map(len, col)) for col in zip(*myList)]
+        formatStr = ' | '.join(["{{:<{}}}".format(i) for i in colSize])
+        myList.insert(1, ['-' * i for i in colSize])  # Seperating line
+        for item in myList: print(formatStr.format(*item))
+        print("")
+
+    def wait_for_ready(self, op_id, check_frequency=15, timeout=-1, verbose=False):
         start_time = time.time()
         time.sleep(0.5)
         while True:
-            state = self.status()
-            if state['status'] == 'ready':
+            state = self.status(op_id)
+            if state['status'] == 'finished':
                 break
 
             elapsed_time = int(time.time() - start_time)
+
             if verbose:
-                print("{} seconds elapsed. status={}. {}/{} indexed. {} frames completed.".format(
-                    int(time.time() - start_time),
-                    state['status'],
-                    state['publish_progress'],
-                    state['num_documents'],
-                    state['size']))
+                self.printTable(state["progress"])
 
             if 0 < timeout < elapsed_time:
                 print("Time out!")
@@ -105,8 +119,8 @@ class SOCOClient(object):
 
         return json.loads(result.text)
 
-    def status(self):
-        result = requests.get(self.status_url, headers=self._get_header())
+    def status(self,op_id):
+        result = requests.get("{}/{}".format(self.status_url,op_id), headers=self._get_header())
         if result.status_code >= 300:
             raise Exception("Error in connecting to the SOCO servers")
 
@@ -160,16 +174,19 @@ class SOCOClient(object):
     def reindex(self, params=None, sync=True):
         body = {'params': params} if params is not None else {}
         result = requests.post(self.publish_url, json=body, headers=self._get_header())
+        rep = result.json()
+
         if result.status_code > 299:
             raise Exception(result.json())
         if sync:
-            self.wait_for_ready(verbose=True)
+            self.wait_for_ready( rep["op_id"], verbose=True)
             print("Index is ready!")
 
         return result
 
     def abort(self, sync=True):
         result = requests.post(self.abort_url, headers=self._get_header())
+        #rep = result.json()
         if sync:
             self.wait_for_ready(verbose=True)
 
